@@ -2,8 +2,8 @@
 # @Author: Anderson
 # @Date:   2019-11-11 17:42:18
 # @Last Modified by:   ander
-# @Last Modified time: 2020-04-17 14:46:12
-from openpyxl import Workbook
+# @Last Modified time: 2020-04-21 16:19:16
+from openpyxl import Workbook, load_workbook
 import requests
 from bs4 import BeautifulSoup
 from urllib.parse import quote_plus
@@ -13,6 +13,7 @@ import jieba
 import os
 import re
 import json
+import csv
 from pyecharts import options as opts
 from pyecharts.charts import Bar
 from pyecharts.charts import WordCloud
@@ -206,9 +207,19 @@ class ExcelBot(object):
 		self.workbook.remove_sheet(self.sheet)
 		self.sheet = self.workbook.create_sheet('sheet1')
 
-	def save(self, filename):
+	def open(self, filename):
+		self.workbook = load_workbook(filename=filename)
+		self.sheet = self.workbook.active
+
+	def save(self, filename, ext='xlsx'):
 		self.filename = filename
-		self.workbook.save(filename=f'{filename}.xlsx')
+		if ext == 'xlsx':
+			self.workbook.save(filename=f'{filename}.xlsx')
+		elif ext == 'csv':
+			with open(f'{filename}.csv', 'w', newline="") as f:
+				c = csv.writer(f)
+				for r in self.sheet.rows:
+					c.writerow([cell.value for cell in r])
 
 
 class PDFBot(object):
